# Flask CSV Analyzer

A simple web application built with Flask and Pandas to upload a CSV file and display basic data analysis.

## Features

* Upload CSV files via a web interface.
* Displays basic information: filename, rows, columns.
* Shows column names and inferred data types.
* Provides a summary equivalent to `pandas.DataFrame.info()`.
* Calculates descriptive statistics (`pandas.DataFrame.describe()`) for numeric columns.
* Displays the first 5 rows (`pandas.DataFrame.head()`).
* Basic error handling for file uploads and processing.

## Setup

1.  **Clone or Download:** Get the project files.
2.  **Create `uploads` Directory:** Inside the `flask_csv_analyzer` directory, create an empty folder named `uploads`:
    ```bash
    mkdir uploads
    ```
    *This folder is required for storing the uploaded CSV files.*
3.  **Create Virtual Environment (Recommended):**
    ```bash
    python -m venv venv
    # On Windows
    venv\Scripts\activate
    # On macOS/Linux
    source venv/bin/activate
    ```
4.  **Install Dependencies:**
    ```bash
    pip install -r requirements.txt
    ```

## Running the Application

1.  **Activate Virtual Environment** (if you created one):
    ```bash
    # On Windows
    venv\Scripts\activate
    # On macOS/Linux
    source venv/bin/activate
    ```
2.  **Run the Flask App:**
    ```bash
    python app.py
    ```
3.  **Access the App:** Open your web browser and go to `http://127.0.0.1:5000/` or `http://localhost:5000/`.

## How to Use

1.  Navigate to the home page.
2.  Click "Choose File" and select a `.csv` file from your computer.
3.  Click "Upload and Analyze".
4.  If the upload and analysis are successful, you will be redirected to a results page showing the analytics.
5.  If there's an error (e.g., wrong file type, empty file, parsing error), a message will be displayed on the home page.

## Notes

* **Security:** This is a basic example. For production, enhance security (e.g., more robust input validation, potentially storing files outside the web root, rate limiting, user authentication). The current `secret_key` is insecure and should be changed.
* **File Size Limit:** The application currently has a 16MB upload limit set in `app.py`. Adjust `MAX_CONTENT_LENGTH` if needed.
* **Large Files:** Processing very large CSV files might be slow or consume significant memory as Pandas loads the entire file. For production scenarios with large data, consider asynchronous processing (e.g., using Celery) or chunked reading.
* **Error Handling:** Basic error handling is included, but can be expanded for more specific CSV parsing issues.